NetMāgus Python Package
=======================

| |Updates| |Python3| |BuildStatus|


This Python package is to be used with the `NetMāgus <http://www.intelligentvisibility.com/netmagus>`_ product from `Intelligent Visbility, Inc <http://www.intelligentvisibility.com>`_.

It is used to create and exchange UI forms and Formula steps with the NetMāgus application.

The code has been tested and should work for both Python 2.7 and 3.5+.

To install, simply use ``pip install netmagus``

Refer to the `NetMāgus <http://www.intelligentvisibility.com/netmagus>`_ documentation for usage details.

.. |Updates| image:: https://pyup.io/repos/github/rbcollins123/netmagus_python/shield.svg?token=fffb8c76-e275-451f-8ce0-1ec463f6d650
    :target: https://pyup.io/repos/github/rbcollins123/netmagus_python/
     :alt: Updates

.. |Python3| image:: https://pyup.io/repos/github/rbcollins123/netmagus_python/python-3-shield.svg?token=fffb8c76-e275-451f-8ce0-1ec463f6d650
    :target: https://pyup.io/repos/github/rbcollins123/netmagus_python/
     :alt: Python3

.. |BuildStatus| image:: https://travis-ci.com/rbcollins123/netmagus_python.svg?token=dqosS7xWadx9zSztAYMC&branch=master
    :target: https://travis-ci.com/rbcollins123/netmagus_python/
     :alt: Build Status